﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using WpfApplication2.Models;

namespace WpfApplication2.ViewModels
{
    public class MainWindowViewModel : BaseViewModel
    {
        private ObservableCollection<Person> people;
        public ObservableCollection<Person> People
        {
            get { return people; }
            set
            {
                people = value;
                RaisePropertyChanged("People");
            }
        }

        private Person currentPerson;
        public Person CurrentPerson
        {
            get { return currentPerson; }
            set
            {
                currentPerson = value;
                RaisePropertyChanged("CurrentPerson");
            }
        }


        public MainWindowViewModel()
        {
            People = new ObservableCollection<Person>(Design.Datas.GetPeople());
            CurrentPerson = People.Skip(1).FirstOrDefault();

            if (DesignerProperties.GetIsInDesignMode(new DependencyObject()))
            {
            }
            else
            {
            }
        }

        DelegateCommand addCommand;
        public DelegateCommand AddCommand
        {
            get
            {
                if (addCommand == null)
                {
                    addCommand = new DelegateCommand(obj =>
                    {
                        CurrentPerson = new Person();
                        CurrentPerson.Id = People.Max(p => p.Id) + 1;
                        People.Add(CurrentPerson);
                    });
                }
                return addCommand;
            }
        }

        DelegateCommand removeCommand;
        public DelegateCommand RemoveCommand
        {
            get
            {
                if (removeCommand == null)
                {
                    removeCommand = new DelegateCommand(obj =>
                    {

                        if (CurrentPerson != null && People.Count(p => p.Id == CurrentPerson.Id) > 0)
                        {
                            People.Remove(CurrentPerson);
                        }
                    });
                }
                return removeCommand;
            }
        }

        DelegateCommand selectChangedCommand;
        public DelegateCommand SelectChangedCommand
        {
            get
            {
                if (selectChangedCommand == null)
                {
                    selectChangedCommand = new DelegateCommand(obj =>
                    {
                        var person = obj as Person;
                        if (person != null && People.Count(p => p.Id == person.Id) > 0)
                        {
                            CurrentPerson = person;
                        }
                    });
                }
                return selectChangedCommand;
            }
        }

        private DelegateCommand loadedCommand;

        public DelegateCommand LoadedCommand
        {
            get 
            {
                if (loadedCommand == null)
                {
                    loadedCommand = new DelegateCommand(
                        args => 
                        {
                            var window = new ReservationWindow();
                            window.Show();
                        });
                }
                return loadedCommand; 
            }
        }

        private DelegateCommand addReservationCommand;

        public DelegateCommand AddReservationCommand
        {
            get 
            {
                if (addReservationCommand == null)
                {
                    addReservationCommand = new DelegateCommand(
                        args => 
                        {
                            if (CurrentPerson != null)
                            {
                                var locator = App.Current.Resources["Locator"] as ViewModelLocator;
                                var reservations = locator.ReservationWindowVM.Reservations;
                                reservations.Add(new Reservation { Idx = reservations.Count, Per = CurrentPerson, RDate = DateTime.Now.ToString("yyyy-MM-dd"), RTime = DateTime.Now.ToString("hh:mm") });
                            }
                        });
                }
                return addReservationCommand; 
            }
        }


    }
}
